@@ -1,7 +1,7 @@
 package App::org2wp;
 
-our $DATE = '2016-12-22'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2017-06-16'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -155,6 +155,11 @@ _
     features => {
         dry_run => 1,
     },
+    links => [
+        {url=>'prog:pod2wp'},
+        {url=>'prog:html2wp'},
+        {url=>'prog:wp-xmlrpc'},
+    ],
 };
 sub org2wp {
     my %args = @_;
@@ -371,12 +376,16 @@ App::org2wp - Publish Org document to WordPress as blog post
 
 =head1 VERSION
 
-This document describes version 0.004 of App::org2wp (from Perl distribution App-org2wp), released on 2016-12-22.
+This document describes version 0.005 of App::org2wp (from Perl distribution App-org2wp), released on 2017-06-16.
 
 =head1 FUNCTIONS
 
 
-=head2 org2wp(%args) -> [status, msg, result, meta]
+=head2 org2wp
+
+Usage:
+
+ org2wp(%args) -> [status, msg, result, meta]
 
 Publish Org document to WordPress as blog post.
 
@@ -531,13 +540,22 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+
+L<pod2wp>.
+
+L<html2wp>.
+
+L<wp-xmlrpc>.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
